@@ -22,8 +22,8 @@ use hvcg_governance_openapi_catholic_polity::{Api, ApiNoContext, Client, Context
                       UpdateParishResponse,
                       AddProvinceResponse,
                       DeleteProvinceResponse,
-                      GetProvinceResponse,
                       GetProvinceByIdResponse,
+                      GetProvincesResponse,
                       UpdateProvinceResponse,
                      };
 use clap::{App, Arg};
@@ -59,8 +59,8 @@ fn main() {
                 "UpdateParish",
                 "AddProvince",
                 "DeleteProvince",
-                "GetProvince",
                 "GetProvinceById",
+                "GetProvinces",
                 "UpdateProvince",
             ])
             .required(true)
@@ -121,8 +121,10 @@ fn main() {
         },
         Some("GetDeaneries") => {
             let result = rt.block_on(client.get_deaneries(
-                  Some("province_name_example".to_string()),
-                  Some("name_example".to_string())
+                  Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
+                  Some("name_example".to_string()),
+                  Some(56),
+                  Some(56)
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
@@ -163,8 +165,11 @@ fn main() {
         },
         Some("GetDioceses") => {
             let result = rt.block_on(client.get_dioceses(
-                  Some("province_name_example".to_string()),
-                  Some("name_example".to_string())
+                  Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
+                  None,
+                  Some("name_example".to_string()),
+                  Some(56),
+                  Some(56)
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
@@ -197,7 +202,7 @@ fn main() {
         },
         Some("GetParishes") => {
             let result = rt.block_on(client.get_parishes(
-                  Some("diocese_name_example".to_string()),
+                  Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
                   Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
                   Some("name_example".to_string()),
                   Some(56),
@@ -224,18 +229,21 @@ fn main() {
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
-        Some("GetProvince") => {
-            let result = rt.block_on(client.get_province(
-                  Some("name_example".to_string())
-            ));
-            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
-        },
         Some("GetProvinceById") => {
             let result = rt.block_on(client.get_province_by_id(
                   serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
+        Some("GetProvinces") => {
+            let result = rt.block_on(client.get_provinces(
+                  Some("name_example".to_string()),
+                  None,
+                  Some(56),
+                  Some(56)
+            ));
+            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
+        },
         Some("UpdateProvince") => {
             let result = rt.block_on(client.update_province(
                   serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example"),
