@@ -113,8 +113,8 @@ use hvcg_governance_openapi_catholic_polity::{
     UpdateParishResponse,
     AddProvinceResponse,
     DeleteProvinceResponse,
-    GetProvinceResponse,
     GetProvinceByIdResponse,
+    GetProvincesResponse,
     UpdateProvinceResponse,
 };
 use hvcg_governance_openapi_catholic_polity::server::MakeService;
@@ -149,12 +149,14 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Get deaneries
     async fn get_deaneries(
         &self,
-        province_name: Option<String>,
+        diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
         context: &C) -> Result<GetDeaneriesResponse, ApiError>
     {
         let context = context.clone();
-        info!("get_deaneries({:?}, {:?}) - X-Span-ID: {:?}", province_name, name, context.get().0.clone());
+        info!("get_deaneries({:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", diocese_id, name, offset, count, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -217,12 +219,15 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Get all dioceses
     async fn get_dioceses(
         &self,
-        province_name: Option<String>,
+        province_id: Option<uuid::Uuid>,
+        province_code: Option<models::Code>,
         name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
         context: &C) -> Result<GetDiocesesResponse, ApiError>
     {
         let context = context.clone();
-        info!("get_dioceses({:?}, {:?}) - X-Span-ID: {:?}", province_name, name, context.get().0.clone());
+        info!("get_dioceses({:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", province_id, province_code, name, offset, count, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -274,7 +279,7 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Get all parishes
     async fn get_parishes(
         &self,
-        diocese_name: Option<String>,
+        deanery_id: Option<uuid::Uuid>,
         diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
         offset: Option<i32>,
@@ -282,7 +287,7 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         context: &C) -> Result<GetParishesResponse, ApiError>
     {
         let context = context.clone();
-        info!("get_parishes({:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", diocese_name, diocese_id, name, offset, count, context.get().0.clone());
+        info!("get_parishes({:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", deanery_id, diocese_id, name, offset, count, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -320,17 +325,6 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         Err("Generic failuare".into())
     }
 
-    /// Get all province
-    async fn get_province(
-        &self,
-        name: Option<String>,
-        context: &C) -> Result<GetProvinceResponse, ApiError>
-    {
-        let context = context.clone();
-        info!("get_province({:?}) - X-Span-ID: {:?}", name, context.get().0.clone());
-        Err("Generic failuare".into())
-    }
-
     /// Find province by ID
     async fn get_province_by_id(
         &self,
@@ -342,6 +336,20 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         Err("Generic failuare".into())
     }
 
+    /// Get all provinces
+    async fn get_provinces(
+        &self,
+        name: Option<String>,
+        province_code: Option<models::Code>,
+        offset: Option<i32>,
+        count: Option<i32>,
+        context: &C) -> Result<GetProvincesResponse, ApiError>
+    {
+        let context = context.clone();
+        info!("get_provinces({:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", name, province_code, offset, count, context.get().0.clone());
+        Err("Generic failuare".into())
+    }
+
     /// Update an existing province
     async fn update_province(
         &self,
