@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.3.0";
+pub const API_VERSION: &'static str = "0.4.0";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -245,10 +245,10 @@ pub enum DeleteProvinceResponse {
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
-pub enum GetProvinceResponse {
+pub enum GetProvinceByIdResponse {
     /// successful operation
     SuccessfulOperation
-    (models::ProvinceCollection)
+    (models::Province)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -259,10 +259,10 @@ pub enum GetProvinceResponse {
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
-pub enum GetProvinceByIdResponse {
+pub enum GetProvincesResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Province)
+    (models::ProvinceCollection)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -310,8 +310,10 @@ pub trait Api<C: Send + Sync> {
     /// Get deaneries
     async fn get_deaneries(
         &self,
-        province_name: Option<String>,
+        diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
         context: &C) -> Result<GetDeaneriesResponse, ApiError>;
 
     /// Find deanery by ID
@@ -348,8 +350,11 @@ pub trait Api<C: Send + Sync> {
     /// Get all dioceses
     async fn get_dioceses(
         &self,
-        province_name: Option<String>,
+        province_id: Option<uuid::Uuid>,
+        province_code: Option<models::Code>,
         name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
         context: &C) -> Result<GetDiocesesResponse, ApiError>;
 
     /// Update an existing diocese
@@ -380,7 +385,7 @@ pub trait Api<C: Send + Sync> {
     /// Get all parishes
     async fn get_parishes(
         &self,
-        diocese_name: Option<String>,
+        deanery_id: Option<uuid::Uuid>,
         diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
         offset: Option<i32>,
@@ -406,18 +411,21 @@ pub trait Api<C: Send + Sync> {
         id: uuid::Uuid,
         context: &C) -> Result<DeleteProvinceResponse, ApiError>;
 
-    /// Get all province
-    async fn get_province(
-        &self,
-        name: Option<String>,
-        context: &C) -> Result<GetProvinceResponse, ApiError>;
-
     /// Find province by ID
     async fn get_province_by_id(
         &self,
         id: uuid::Uuid,
         context: &C) -> Result<GetProvinceByIdResponse, ApiError>;
 
+    /// Get all provinces
+    async fn get_provinces(
+        &self,
+        name: Option<String>,
+        province_code: Option<models::Code>,
+        offset: Option<i32>,
+        count: Option<i32>,
+        context: &C) -> Result<GetProvincesResponse, ApiError>;
+
     /// Update an existing province
     async fn update_province(
         &self,
@@ -450,8 +458,10 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Get deaneries
     async fn get_deaneries(
         &self,
-        province_name: Option<String>,
+        diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
         ) -> Result<GetDeaneriesResponse, ApiError>;
 
     /// Find deanery by ID
@@ -488,8 +498,11 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Get all dioceses
     async fn get_dioceses(
         &self,
-        province_name: Option<String>,
+        province_id: Option<uuid::Uuid>,
+        province_code: Option<models::Code>,
         name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
         ) -> Result<GetDiocesesResponse, ApiError>;
 
     /// Update an existing diocese
@@ -520,7 +533,7 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Get all parishes
     async fn get_parishes(
         &self,
-        diocese_name: Option<String>,
+        deanery_id: Option<uuid::Uuid>,
         diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
         offset: Option<i32>,
@@ -546,18 +559,21 @@ pub trait ApiNoContext<C: Send + Sync> {
         id: uuid::Uuid,
         ) -> Result<DeleteProvinceResponse, ApiError>;
 
-    /// Get all province
-    async fn get_province(
-        &self,
-        name: Option<String>,
-        ) -> Result<GetProvinceResponse, ApiError>;
-
     /// Find province by ID
     async fn get_province_by_id(
         &self,
         id: uuid::Uuid,
         ) -> Result<GetProvinceByIdResponse, ApiError>;
 
+    /// Get all provinces
+    async fn get_provinces(
+        &self,
+        name: Option<String>,
+        province_code: Option<models::Code>,
+        offset: Option<i32>,
+        count: Option<i32>,
+        ) -> Result<GetProvincesResponse, ApiError>;
+
     /// Update an existing province
     async fn update_province(
         &self,
@@ -613,12 +629,14 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Get deaneries
     async fn get_deaneries(
         &self,
-        province_name: Option<String>,
+        diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
         ) -> Result<GetDeaneriesResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_deaneries(province_name, name, &context).await
+        self.api().get_deaneries(diocese_id, name, offset, count, &context).await
     }
 
     /// Find deanery by ID
@@ -675,12 +693,15 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Get all dioceses
     async fn get_dioceses(
         &self,
-        province_name: Option<String>,
+        province_id: Option<uuid::Uuid>,
+        province_code: Option<models::Code>,
         name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
         ) -> Result<GetDiocesesResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_dioceses(province_name, name, &context).await
+        self.api().get_dioceses(province_id, province_code, name, offset, count, &context).await
     }
 
     /// Update an existing diocese
@@ -727,7 +748,7 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Get all parishes
     async fn get_parishes(
         &self,
-        diocese_name: Option<String>,
+        deanery_id: Option<uuid::Uuid>,
         diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
         offset: Option<i32>,
@@ -735,7 +756,7 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         ) -> Result<GetParishesResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_parishes(diocese_name, diocese_id, name, offset, count, &context).await
+        self.api().get_parishes(deanery_id, diocese_id, name, offset, count, &context).await
     }
 
     /// Update an existing parish
@@ -769,16 +790,6 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         self.api().delete_province(id, &context).await
     }
 
-    /// Get all province
-    async fn get_province(
-        &self,
-        name: Option<String>,
-        ) -> Result<GetProvinceResponse, ApiError>
-    {
-        let context = self.context().clone();
-        self.api().get_province(name, &context).await
-    }
-
     /// Find province by ID
     async fn get_province_by_id(
         &self,
@@ -789,6 +800,19 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         self.api().get_province_by_id(id, &context).await
     }
 
+    /// Get all provinces
+    async fn get_provinces(
+        &self,
+        name: Option<String>,
+        province_code: Option<models::Code>,
+        offset: Option<i32>,
+        count: Option<i32>,
+        ) -> Result<GetProvincesResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().get_provinces(name, province_code, offset, count, &context).await
+    }
+
     /// Update an existing province
     async fn update_province(
         &self,
