@@ -193,12 +193,17 @@ pub struct DeaneryCollection {
     #[serde(skip_serializing_if="Option::is_none")]
     pub deaneries: Option<Vec<models::Deanery>>,
 
+    #[serde(rename = "hasMore")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub has_more: Option<bool>,
+
 }
 
 impl DeaneryCollection {
     pub fn new() -> DeaneryCollection {
         DeaneryCollection {
             deaneries: None,
+            has_more: None,
         }
     }
 }
@@ -211,6 +216,12 @@ impl std::string::ToString for DeaneryCollection {
         let mut params: Vec<String> = vec![];
         // Skipping deaneries in query parameter serialization
 
+
+        if let Some(ref has_more) = self.has_more {
+            params.push("hasMore".to_string());
+            params.push(has_more.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -226,6 +237,7 @@ impl std::str::FromStr for DeaneryCollection {
         // An intermediate representation of the struct to use for parsing.
         struct IntermediateRep {
             pub deaneries: Vec<Vec<models::Deanery>>,
+            pub has_more: Vec<bool>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -243,6 +255,7 @@ impl std::str::FromStr for DeaneryCollection {
             if let Some(key) = key_result {
                 match key {
                     "deaneries" => return std::result::Result::Err("Parsing a container in this style is not supported in DeaneryCollection".to_string()),
+                    "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing DeaneryCollection".to_string())
                 }
             }
@@ -254,6 +267,7 @@ impl std::str::FromStr for DeaneryCollection {
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(DeaneryCollection {
             deaneries: intermediate_rep.deaneries.into_iter().next(),
+            has_more: intermediate_rep.has_more.into_iter().next(),
         })
     }
 }
@@ -302,8 +316,7 @@ impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderVal
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 pub struct Diocese {
     #[serde(rename = "province")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub province: Option<models::Province>,
+    pub province: models::Province,
 
     #[serde(rename = "id")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -318,9 +331,9 @@ pub struct Diocese {
 }
 
 impl Diocese {
-    pub fn new(name: String, person_in_charge: String, ) -> Diocese {
+    pub fn new(province: models::Province, name: String, person_in_charge: String, ) -> Diocese {
         Diocese {
-            province: None,
+            province: province,
             id: None,
             name: name,
             person_in_charge: person_in_charge,
@@ -394,7 +407,7 @@ impl std::str::FromStr for Diocese {
 
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(Diocese {
-            province: intermediate_rep.province.into_iter().next(),
+            province: intermediate_rep.province.into_iter().next().ok_or("province missing in Diocese".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Diocese".to_string())?,
             person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Diocese".to_string())?,
@@ -448,12 +461,17 @@ pub struct DioceseCollection {
     #[serde(skip_serializing_if="Option::is_none")]
     pub dioceses: Option<Vec<models::Diocese>>,
 
+    #[serde(rename = "hasMore")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub has_more: Option<bool>,
+
 }
 
 impl DioceseCollection {
     pub fn new() -> DioceseCollection {
         DioceseCollection {
             dioceses: None,
+            has_more: None,
         }
     }
 }
@@ -466,6 +484,12 @@ impl std::string::ToString for DioceseCollection {
         let mut params: Vec<String> = vec![];
         // Skipping dioceses in query parameter serialization
 
+
+        if let Some(ref has_more) = self.has_more {
+            params.push("hasMore".to_string());
+            params.push(has_more.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -481,6 +505,7 @@ impl std::str::FromStr for DioceseCollection {
         // An intermediate representation of the struct to use for parsing.
         struct IntermediateRep {
             pub dioceses: Vec<Vec<models::Diocese>>,
+            pub has_more: Vec<bool>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -498,6 +523,7 @@ impl std::str::FromStr for DioceseCollection {
             if let Some(key) = key_result {
                 match key {
                     "dioceses" => return std::result::Result::Err("Parsing a container in this style is not supported in DioceseCollection".to_string()),
+                    "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing DioceseCollection".to_string())
                 }
             }
@@ -509,6 +535,7 @@ impl std::str::FromStr for DioceseCollection {
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(DioceseCollection {
             dioceses: intermediate_rep.dioceses.into_iter().next(),
+            has_more: intermediate_rep.has_more.into_iter().next(),
         })
     }
 }
@@ -1101,12 +1128,17 @@ pub struct ProvinceCollection {
     #[serde(skip_serializing_if="Option::is_none")]
     pub parishes: Option<Vec<models::Province>>,
 
+    #[serde(rename = "hasMore")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub has_more: Option<bool>,
+
 }
 
 impl ProvinceCollection {
     pub fn new() -> ProvinceCollection {
         ProvinceCollection {
             parishes: None,
+            has_more: None,
         }
     }
 }
@@ -1119,6 +1151,12 @@ impl std::string::ToString for ProvinceCollection {
         let mut params: Vec<String> = vec![];
         // Skipping parishes in query parameter serialization
 
+
+        if let Some(ref has_more) = self.has_more {
+            params.push("hasMore".to_string());
+            params.push(has_more.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -1134,6 +1172,7 @@ impl std::str::FromStr for ProvinceCollection {
         // An intermediate representation of the struct to use for parsing.
         struct IntermediateRep {
             pub parishes: Vec<Vec<models::Province>>,
+            pub has_more: Vec<bool>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -1151,6 +1190,7 @@ impl std::str::FromStr for ProvinceCollection {
             if let Some(key) = key_result {
                 match key {
                     "parishes" => return std::result::Result::Err("Parsing a container in this style is not supported in ProvinceCollection".to_string()),
+                    "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing ProvinceCollection".to_string())
                 }
             }
@@ -1162,6 +1202,7 @@ impl std::str::FromStr for ProvinceCollection {
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(ProvinceCollection {
             parishes: intermediate_rep.parishes.into_iter().next(),
+            has_more: intermediate_rep.has_more.into_iter().next(),
         })
     }
 }
